@@ -55,12 +55,12 @@ AnalyzedResourceSummaryTypeDef = TypedDict(
         "resourceArn": str,
         "resourceOwnerAccount": str,
         "resourceType": Literal[
+            "AWS::S3::Bucket",
             "AWS::IAM::Role",
-            "AWS::KMS::Key",
+            "AWS::SQS::Queue",
             "AWS::Lambda::Function",
             "AWS::Lambda::LayerVersion",
-            "AWS::S3::Bucket",
-            "AWS::SQS::Queue",
+            "AWS::KMS::Key",
         ],
     },
 )
@@ -74,12 +74,12 @@ _RequiredAnalyzedResourceTypeDef = TypedDict(
         "resourceArn": str,
         "resourceOwnerAccount": str,
         "resourceType": Literal[
+            "AWS::S3::Bucket",
             "AWS::IAM::Role",
-            "AWS::KMS::Key",
+            "AWS::SQS::Queue",
             "AWS::Lambda::Function",
             "AWS::Lambda::LayerVersion",
-            "AWS::S3::Bucket",
-            "AWS::SQS::Queue",
+            "AWS::KMS::Key",
         ],
         "updatedAt": datetime,
     },
@@ -147,7 +147,7 @@ FindingSourceDetailTypeDef = TypedDict(
 )
 
 _RequiredFindingSourceTypeDef = TypedDict(
-    "_RequiredFindingSourceTypeDef", {"type": Literal["BUCKET_ACL", "POLICY", "S3_ACCESS_POINT"]}
+    "_RequiredFindingSourceTypeDef", {"type": Literal["POLICY", "BUCKET_ACL", "S3_ACCESS_POINT"]}
 )
 _OptionalFindingSourceTypeDef = TypedDict(
     "_OptionalFindingSourceTypeDef", {"detail": "FindingSourceDetailTypeDef"}, total=False
@@ -167,12 +167,12 @@ _RequiredFindingSummaryTypeDef = TypedDict(
         "id": str,
         "resourceOwnerAccount": str,
         "resourceType": Literal[
+            "AWS::S3::Bucket",
             "AWS::IAM::Role",
-            "AWS::KMS::Key",
+            "AWS::SQS::Queue",
             "AWS::Lambda::Function",
             "AWS::Lambda::LayerVersion",
-            "AWS::S3::Bucket",
-            "AWS::SQS::Queue",
+            "AWS::KMS::Key",
         ],
         "status": Literal["ACTIVE", "ARCHIVED", "RESOLVED"],
         "updatedAt": datetime,
@@ -205,12 +205,12 @@ _RequiredFindingTypeDef = TypedDict(
         "id": str,
         "resourceOwnerAccount": str,
         "resourceType": Literal[
+            "AWS::S3::Bucket",
             "AWS::IAM::Role",
-            "AWS::KMS::Key",
+            "AWS::SQS::Queue",
             "AWS::Lambda::Function",
             "AWS::Lambda::LayerVersion",
-            "AWS::S3::Bucket",
-            "AWS::SQS::Queue",
+            "AWS::KMS::Key",
         ],
         "status": Literal["ACTIVE", "ARCHIVED", "RESOLVED"],
         "updatedAt": datetime,
